VoteTestExt

Trait VoteTestExt 

pub trait VoteTestExt<T: CertificateValue>: Sized {
    // Required method
    fn into_certificate(
        self,
        public_key: ValidatorPublicKey,
    ) -> GenericCertificate<T>;
}
Helper trait to simplify creating certificates from votes in tests.

Required Methods

fn into_certificate( self, public_key: ValidatorPublicKey, ) -> GenericCertificate<T>

Returns a certificate for a committee consisting only of this validator.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors